/*
Copyright © 2025 Jake jake.young.dev@gmail.com
*/
package command

import (
	"errors"
	"fmt"

	"code.jakeyoungdev.com/jake/mctl/database"
	"github.com/spf13/cobra"
)

var deleteCmd = &cobra.Command{
	Use:          "delete",
	Example:      "mctl command delete <name>",
	Short:        "Deletes a command from the database",
	SilenceUsage: true,
	Run: func(cmd *cobra.Command, args []string) {
		db, err := database.New()
		cobra.CheckErr(err)
		defer db.Close()

		err = db.DeleteCmd(args[0])
		if err != nil {
			if err.Error() == ErrInit {
				fmt.Println(ErrInitRsp)
				return
			}
		}
		cobra.CheckErr(err)

		fmt.Println("Command deleted")
	},
	PreRunE: func(cmd *cobra.Command, args []string) error {
		if len(args) == 0 {
			return errors.New("name parameter missing")
		}
		return nil
	},
}

func init() {
	CommandCmd.AddCommand(deleteCmd)
}
