/*
Copyright © 2025 Jake jake.young.dev@gmail.com
*/
package server

import (
	"fmt"

	"code.jakeyoungdev.com/jake/mctl/database"
	"github.com/spf13/cobra"
)

var viewCmd = &cobra.Command{
	Use:          "view",
	Example:      "mctl server view",
	Short:        "view all saved servers",
	SilenceUsage: true,
	Run: func(cmd *cobra.Command, args []string) {
		db, err := database.New()
		cobra.CheckErr(err)
		defer db.Close()

		ts, err := db.GetAllServers()
		if err != nil {
			if err.Error() == ErrInit {
				fmt.Println(ErrInitRsp)
				return
			}
		}
		cobra.CheckErr(err)

		for _, s := range ts {
			fmt.Println("-----")
			fmt.Printf("Name: %s\n", s.Name)
			fmt.Printf("Address: %s\n", s.Server)
			fmt.Printf("Port: %d\n", s.Port)
			fmt.Println("Password: [REDACTED]")
			fmt.Printf("Default: %t\n", s.Active)
		}
	},
}

func init() {
	ServerCmd.AddCommand(viewCmd)
}
